

# THIRD-PARTY NOTICES (Copyright & Attributions)

Copyright © 2025 Hancom, Inc. All rights reserved.

Below are copyright and notice texts for third-party libraries and components used in this project.
Full license texts are provided in the `licenses/` directory.
See also: [THIRD_PARTY_LICENSES](THIRD_PARTY_LICENSES.md) for details.

---

##### Apache Software Foundation notices

The following components include software developed at The Apache Software Foundation (https://www.apache.org/).

- Apache Commons Logging
- Apache PDFBox Family (FontBox / PDFBox / PDFBox-IO)
- Apache Commons CLI
- Apache Maven family (maven-artifact, maven-artifact-manager, maven-plugin-api, maven-reporting-api,
  maven-repository-metadata, maven-shared-file-management, maven-shared-io, wagon-provider-api)
- Apache Maven Doxia (doxia-sink-api)

"This product includes software developed at The Apache Software Foundation (https://www.apache.org/)."

---

##### API Guardian

###### API Guardian (`org.apiguardian:apiguardian-api:1.1.0`)
(C) 1995–2013 Jean-loup Gailly and Mark Adler  
(c) 2009–2016 Stuart Knightley  
(c) 2014 Stuart Knightley, David Duponchel  
(C) 2014–2017 Vitaly Puzrin and Andrey Tupitsin  
Copyright (c) 2013, 2015, 2018 Oracle and/or its affiliates. All rights reserved  
Copyright 2002–2017 the original author or authors.  
Copyright 2015 jQuery Foundation and other contributors

---

##### Apache Commons Logging

###### Commons Logging (`commons-logging:commons-logging:1.3.4`)  
Copyright 2001-2024 The Apache Software Foundation

---

##### Apache Maven Doxia

###### Doxia Sitetools / doxia-sink-api (`org.apache.maven.doxia:doxia-sink-api:1.0`)  
Copyright 2005-2009 The Apache Software Foundation

---

##### Apache Maven family

###### Maven Artifact (`org.apache.maven:maven-artifact:2.0.2`)  
Copyright 2001-2005 The Apache Software Foundation.
Copyright 2006 Apache Software Foundation. All Rights Reserved

###### Maven Artifact Manager (`org.apache.maven:maven-artifact-manager:2.0.2`)  
Copyright 2001-2005 The Apache Software Foundation.
Copyright 2006 Apache Software Foundation. All Rights Reserved

###### Maven Plugin API (`org.apache.maven:maven-plugin-api:2.0.6`)  
Copyright 2001-2007 The Apache Software Foundation

###### Maven Reporting API (`org.apache.maven.reporting:maven-reporting-api:3.0`)  
Copyright 2002-2010 The Apache Software Foundation

###### Maven Shared File Management (`org.apache.maven.shared:maven-shared-file-management:1.2.1`)  
Copyright 2002-2009 The Apache Software Foundation

###### Maven Shared I/O (`org.apache.maven.shared:maven-shared-io:1.1`)  
Copyright 2002-2007 The Apache Software Foundation

###### Maven Wagon API (`org.apache.maven.wagon:wagon-provider-api:1.0-alpha-6`)  
Copyright 2001–2005 The Apache Software Foundation.

---

##### Apache PDFBox family

###### FontBox (`org.apache.pdfbox:fontbox:3.0.4`)  
Copyright (c) 2006-2007 www.fontbox.org
Copyright 2008-2024 The Apache Software Foundation

###### PDFBox (`org.apache.pdfbox:pdfbox:3.0.4`)  
Copyright (c) 1997-1998, 2002, 2007 Adobe Systems Incorporated
Copyright (c) 2002-2007 www.pdfbox.org
Copyright (c) 2008-2016 Harald Kuhr
copyright (c) 2010 Google Corporation
Copyright (c) 2012 Red Hat, Inc.
Copyright 1990-2010 Adobe Systems Incorporated.
Copyright 1991-2015 Unicode, Inc.
Copyright 2002-2024 The Apache Software Foundation

###### PDFBox-IO (`org.apache.pdfbox:pdfbox-io:3.0.4`)  
Copyright 2002-2024 The Apache Software Foundation
Copyright 2022 The Apache Software Foundation.

---

##### classworlds (`classworlds:classworlds:1.1-alpha-2`)
Copyright 2002 (C) The Codehaus. All Rights Reserved

---

##### Commons CLI (`commons-cli:commons-cli:1.4`)
Copyright 2001-2017 The Apache Software Foundation

---

##### Default Plexus Container (`org.codehaus.plexus:plexus-container-default:1.0-alpha-9`)
Copyright (c) 1997–2003 The Apache Software Foundation  
Copyright (c) 2004–2005 The Codehaus

---

##### Jackson family (2.15.0)

###### jackson-annotations (`com.fasterxml.jackson.core:jackson-annotations:2.15.0`)  
Copyright 2007, Tatu Saloranta (tatu.saloranta@iki.fi) Licensing

###### jackson-core (`com.fasterxml.jackson.core:jackson-core:2.15.0`)  
Copyright 2007, Tatu Saloranta (tatu.saloranta@iki.fi) Licensing
Copyright 2018-2020 Raffaello Giulietti

###### jackson-databind (`com.fasterxml.jackson.core:jackson-databind:2.15.0`)  
Copyright 2007, Tatu Saloranta (tatu.saloranta@iki.fi) Licensing
Copyright 2010-2011 Google Inc. All Rights Reserved

---

##### JaCoCo (`org.jacoco:*:0.8.10`)
Copyright (c) 2009, 2023 Mountainminds GmbH
(Report module portions) Copyright (C) 2006 Google Inc.

---

##### JAI ImageIO

###### Core (`com.github.jai-imageio:jai-imageio-core:1.4.0`)  
(c) Wang Labs, Inc. 1990-1991
Copyright (c) 2005-2007 Sun Microsystems, Inc. All Rights Reserved
Copyright © 2010-2018 Stian Soiland-Reyes
Copyright © 2010-2018 University of Manchester
Copyright © 2015 Butch Howard
Copyright © 2015 Mark Carroll
Copyright © 2015 Peter Hull
Copyright © 2015 Robin Stevens
Copyright © 2015 Yannick De Turck
Copyright © 2015-2016 Luca Bellonda
Copyright © 2017 Curtis Rueden
Copyright © 2017 Ghislain Bonamy
Copyright © 2017 Mykola Pavluchynskyi
Copyright © 2017 Roger Leigh
Copyright © 2017 Sebastien Besson
Copyright © 2018 Peter Jodeleit All Rights Reserved



###### JPEG2000 (`com.github.jai-imageio:jai-imageio-jpeg2000:1.3.0`)  
Copyright (c) 1999/2000 JJ2000 Partners.
Copyright (c) 2005-2006 Sun Microsystems, Inc. All Rights Reserved

---

##### Jakarta Activation / JAXB

###### Jakarta Activation API (`javax.activation:javax.activation-api:1.2.0`)  
Copyright (C) 1989, 1991 Free Software Foundation, Inc.  
Copyright (C) 1997–2017 Oracle and/or its affiliates. All rights reserved.

###### JAXB Core (`com.sun.xml.bind:jaxb-core:2.3.0.1`)  
(c) 2009–2014 Stuart Knightley
(c) 2014 Stuart Knightley, David Duponchel  
Copyright (c) 1997-2017 Oracle and/or its affiliates. All rights reserved

###### JAXB API (`javax.xml.bind:jaxb-api:2.4.0-b180830.0359`)  
(c) 2009–2014 Stuart Knightley
(c) 2014 Stuart Knightley, David Duponchel  
Copyright (C) 1989, 1991 Free Software Foundation, Inc. 
Copyright (c) 2003-2018 Oracle and/or its affiliates. All rights reserved
Copyright © 2004-2017 Oracle

###### JAXB Implementation (`com.sun.xml.bind:jaxb-impl:2.3.2`)
(C) 1995–2013 Jean-loup Gailly and Mark Adler  
(c) 2009–2016 Stuart Knightley  
(c) 2014 Stuart Knightley, David Duponchel  
(C) 2014–2017 Vitaly Puzrin and Andrey Tupitsin  
© 1997, 2011, 2013–2015, 2017, 2018 Oracle and/or its affiliates. All rights reserved  
© 2015 jQuery Foundation and other contributors

---

##### JUnit / JUnit Platform / opentest4j

###### JUnit Jupiter (Aggregator) (`org.junit.jupiter:junit-jupiter:5.6.2`)  
Copyright 2015-2020 the original author or authors.

###### JUnit Jupiter API / Engine / Params (`5.6.2`)  
Copyright 2015-2020 the original author or authors.

###### JUnit Platform Commons / Engine (`1.6.2`)  
Copyright 2015-2020 the original author or authors.

###### opentest4j (`org.opentest4j:opentest4j:1.2.0`)  
Copyright 2015-2018 the original author or authors.

---

##### Mozilla Rhino (`org.mozilla:rhino:1.7.13`)
Copyright (c) 1991, 2000-2001 by Lucent Technologies
Copyright 1997-1998 Sun Microsystems, Inc. All Rights Reserved
Copyright 2010-2011 the V8 project authors. All rights reserved

---

##### OW2 ASM family

###### ASM (`org.ow2.asm:asm:9.5`), ASM Commons (`org.ow2.asm:asm-commons:9.5`), ASM Tree (`org.ow2.asm:asm-tree:9.5`)  
Copyright (c) 2000–2011 INRIA, France Telecom. All rights reserved.

---

##### PDFBox JBIG2 ImageIO plugin (`org.apache.pdfbox:jbig2-imageio:3.0.3`)
Copyright (C) 1995-2017 levigo holding GmbH
Copyright 2017, 2019 The Apache Software Foundation

---

##### plexus-utils (`org.codehaus.plexus:plexus-utils:3.0.24`)
Copyright (c) The Apache Software Foundation. All rights reserved.  
Copyright (c) 2001–2003 ThoughtWorks, Inc.  
Copyright (C) 2003 The Trustees of Indiana University. All rights reserved
Copyright (c) 2006 Javolution (http://javolution.org) All rights reserved
Copyright 2003-2004 The Apache Software Foundation.
Copyright 2004 Sun Microsystems, Inc.
Copyright 2007, 2011 The Codehaus Foundation.

---

##### StAX Utilities Project (`net.java.dev.stax-utils:stax-utils:20070216`)
Copyright (c) 2004 Christian Niles (Unit12 / unit12.net)  
Copyright (c) 2004 Sun Microsystems, Inc.  
Copyright (c) 2006 John Kristian

---

##### veraPDF components (project uses MPL-2.0)
This project uses the following veraPDF components:  
`org.verapdf:core`, `metadata-fixer`, `parser`, `pdf-model`, `validation-model`,  `verapdf-xmp-core`, `wcag-algorithms`, `wcag-validation` (see `THIRD_PARTY_LICENSES.md` for versions)

Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
All rights reserved.


